@@ -11,18 +11,18 @@ Gmail::Mailbox::Validate - Find if the username has a valid mailbox in gmail
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 
 =head1 SYNOPSIS
 
 This module just checks if the given username has a valid mailbox in gmail.
 
-If you find any issues in using the module, please don't hesitate to email me: pyh@pobox.com
+If you find any issues in using the module, please don't hesitate to email me: hkperl-01@yahoo.com 
 
 
     use Gmail::Mailbox::Validate;
@@ -38,7 +38,7 @@ Or run with docker:
 
     $ docker run geekml/gmbox mytest
 
-Plese notice:
+Plese note:
 
 1. Your host running this program should have access to port 25 of gmail servers. Many providers disable users to access external SMTP port.
 
